# Galigeopy - A Python Package for Galigeo tools
***Jules Pierrat - 02nd of September 2024***

## Introduction

Fugiat quis occaecat velit ea cillum ad exercitation aute duis tempor id. Sint ex pariatur nostrud amet labore veniam ad adipisicing commodo exercitation aliquip nostrud officia. Officia sint exercitation cupidatat laboris consequat et nisi do commodo occaecat aliquip. Dolor sit exercitation qui mollit excepteur dolore veniam quis.

## Setup

__Require:__ Python3

Clone this repository and enter it : 

```bash
# Clone repository
git clone https://github.com/JPTGGO/galigeopy.git

# Enter repository
cd galigeopy
```

Create virtual environment and install dependencies

```bash
# Create virtual environment
python3 -m venv env

# Install dependencies
./env/bin/python3 -m pip install -r requirements.txt
```

Activate environment

```bash
# Activate virtual environment
source ./env/bin/activate
```

Deactivate environment

```bash
# Activate virtual environment
deactivate
```

## Build

Build the wheel package

```bash
# Build the wheel package
./env/bin/python3 setup.py bdist_wheel
```
